%define _buildid .15

%global py26nvr python26-docutils-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr python27-docutils-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

%bcond_without tests # with

%global upstream_name docutils

Name: python-docutils
Version: 0.11
Release: 1%{?_buildid}%{?dist}
Summary: System for processing plaintext documentation
Group: System Environment/Libraries
License: Public Domain and BSD and Python and GPLv3+
URL: http://docutils.sourceforge.net
Source0: http://downloads.sourceforge.net/docutils/%{upstream_name}-%{version}.tar.gz
# Sometimes we need snapshots.  Instructions below:
#  svn co -r 7687 svn://svn.code.sf.net/p/docutils/code/trunk/docutils
#  cd docutils
#  python setup.py sdist
# The tarball is in dist/docutils-VERSION.tar.gz
#Source0: %{upstream_name}-%{version}.tar.gz

# Disable some tests known to fail with Python 3.3
# Bug reports filed upstream as:
#  https://sourceforge.net/tracker/?func=detail&aid=3555164&group_id=38414&atid=422030
Patch100: disable-failing-tests.patch
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python26
BuildRequires: python27

%description
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write. The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals). Work is underway to parse rST from
Python inline documentation modules and packages.

%package -n python26-docutils
Summary: System for processing plaintext documentation
BuildRequires: python26-devel
BuildRequires: python26-setuptools
BuildRequires: python26-unittest2
Requires: python26(alternatives)
Requires: alternatives(addslave)
Requires: alternatives(removeslave)
Requires: alternatives(force)
Requires(preun): python26(alternatives)
Requires(preun): alternatives(removeslave)
Requires: python26-imaging
Provides: python-docutils = %{version}-%{release}
Provides: docutils = %{version}-%{release}
Obsoletes: docutils <= 0.11-1.11.amzn1
Obsoletes: python-docutils <= 0.11-1.11.amzn1

%description -n python26-docutils
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write. The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals). Work is underway to parse rST from
Python inline documentation modules and packages.

This package is meant to be used with Python 2.6.

%package -n python27-docutils
Summary: System for processing plaintext documentation
BuildRequires: python27-devel
BuildRequires: python27-setuptools
BuildRequires: python27-unittest2
Requires: python27(alternatives)
Requires: alternatives(addslave)
Requires: alternatives(removeslave)
Requires: alternatives(force)
Requires(preun): python27(alternatives)
Requires(preun): alternatives(removeslave)
Requires: python27-imaging
Conflicts: python-docutils <= 0.11-1.11.amzn1

%description -n python27-docutils
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write. The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals). Work is underway to parse rST from
Python inline documentation modules and packages.

This package is meant to be used with Python 2.7.

%prep
%setup -q -n %{upstream_name}-%{version}
%patch100 -p1 -b .disable-failing-tests

# Remove shebang from library files
for file in \
  docutils/utils/{code_analyzer.py,punctuation_chars.py,error_reporting.py,smartquotes.py} \
  docutils/utils/math/{latex2mathml.py,math2html.py} \
  docutils/writers/xetex/__init__.py ;
do
  sed -i -e '/#! *\/usr\/bin\/.*/{1D}' $file
done

IDEAS="tools/editors/emacs/IDEAS.rst"
iconv -f ISO88592 -t UTF8 ${IDEAS} > ${IDEAS}.iconv
mv ${IDEAS}{.iconv,}

%build
rm -rf %{py26builddir}
mkdir -p %{py26builddir}
cp -a * %{py26builddir}
pushd %{py26builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python26} setup.py build 
popd

rm -rf %{py27builddir}
mkdir -p %{py27builddir}
cp -a * %{py27builddir}
pushd %{py27builddir}
CFLAGS="$RPM_OPT_FLAGS" %{__python27} setup.py build 
popd

%install
rm -rf %{buildroot}

pushd %{py26builddir}
%{__python26} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

# docutils setup.py runs 2to3 on a copy of the tests and puts it in sitelib.
rm -rf %{buildroot}%{python26_sitelib}/test

pushd %{py26builddir}
# Flash file is used for testing docutils but shouldn't be in the installed package.
mv docs/user/rst/images/biohazard.swf ./biohazard.swf

# We want the licenses but don't need this build file
rm -f licenses/docutils.conf
popd

for file in %{buildroot}/%{_bindir}/*.py ; do
  mv ${file} ${file%.py}-2.6
done

pushd %{py27builddir}
%{__python27} setup.py install -O1 --skip-build --root %{buildroot} --install-layout=amzn
popd

# docutils setup.py runs 2to3 on a copy of the tests and puts it in sitelib.
rm -rf %{buildroot}%{python27_sitelib}/test

pushd %{py27builddir}
# Flash file is used for testing docutils but shouldn't be in the installed package.
mv docs/user/rst/images/biohazard.swf ./biohazard.swf

# We want the licenses but don't need this build file
rm -f licenses/docutils.conf
popd

for file in %{buildroot}/%{_bindir}/*.py ; do
  mv ${file} ${file%.py}-2.7
done

%check
%if %{with tests}
pushd %{py26builddir}
mv biohazard.swf docs/user/rst/images/biohazard.swf
%{__python26} test/alltests.py
rm docs/user/rst/images/biohazard.swf
popd
pushd %{py27builddir}
mv biohazard.swf docs/user/rst/images/biohazard.swf
%{__python27} test/alltests.py
rm docs/user/rst/images/biohazard.swf
popd
%endif

%clean
rm -rf %{buildroot}
rm -rf %{py26builddir}
rm -rf %{py27builddir}

%triggerin -n python26-docutils -- python26
# Refresh alternatives when updating python26-docutils or python26.
%{_sbindir}/update-alternatives \
  --force \
  --update python %{_bindir}/python2.6 \
  --addslave %{_bindir}/rst2html rst2html %{_bindir}/rst2html-2.6 \
  --addslave %{_bindir}/rst2latex rst2latex %{_bindir}/rst2latex-2.6 \
  --addslave %{_bindir}/rst2man rst2man %{_bindir}/rst2man-2.6 \
  --addslave %{_bindir}/rst2odt rst2odt %{_bindir}/rst2odt-2.6 \
  --addslave %{_bindir}/rst2odt_prepstyles rst2odt_prepstyles %{_bindir}/rst2odt_prepstyles-2.6 \
  --addslave %{_bindir}/rst2pseudoxml rst2pseudoxml %{_bindir}/rst2pseudoxml-2.6 \
  --addslave %{_bindir}/rst2s5 rst2s5 %{_bindir}/rst2s5-2.6 \
  --addslave %{_bindir}/rst2xetex rst2xetex %{_bindir}/rst2xetex-2.6 \
  --addslave %{_bindir}/rst2xml rst2xml %{_bindir}/rst2xml-2.6 \
  --addslave %{_bindir}/rstpep2html rstpep2html %{_bindir}/rstpep2html-2.6 \
  || :

%preun -n python26-docutils
if [ $1 -eq 0 ]; then
  %{_sbindir}/update-alternatives \
    --update python %{_bindir}/python2.6 \
    --removeslave rst2html \
    --removeslave rst2latex \
    --removeslave rst2man \
    --removeslave rst2odt \
    --removeslave rst2odt_prepstyles \
    --removeslave rst2pseudoxml \
    --removeslave rst2s5 \
    --removeslave rst2xetex \
    --removeslave rst2xml \
    --removeslave rstpep2html \
 || :
fi

%triggerin -n python27-docutils -- python27
# Refresh alternatives when updating python27-docutils or python27.
%{_sbindir}/update-alternatives \
  --force \
  --update python %{_bindir}/python2.7 \
  --addslave %{_bindir}/rst2html rst2html %{_bindir}/rst2html-2.7 \
  --addslave %{_bindir}/rst2latex rst2latex %{_bindir}/rst2latex-2.7 \
  --addslave %{_bindir}/rst2man rst2man %{_bindir}/rst2man-2.7 \
  --addslave %{_bindir}/rst2odt rst2odt %{_bindir}/rst2odt-2.7 \
  --addslave %{_bindir}/rst2odt_prepstyles rst2odt_prepstyles %{_bindir}/rst2odt_prepstyles-2.7 \
  --addslave %{_bindir}/rst2pseudoxml rst2pseudoxml %{_bindir}/rst2pseudoxml-2.7 \
  --addslave %{_bindir}/rst2s5 rst2s5 %{_bindir}/rst2s5-2.7 \
  --addslave %{_bindir}/rst2xetex rst2xetex %{_bindir}/rst2xetex-2.7 \
  --addslave %{_bindir}/rst2xml rst2xml %{_bindir}/rst2xml-2.7 \
  --addslave %{_bindir}/rstpep2html rstpep2html %{_bindir}/rstpep2html-2.7 \
  || :

%preun -n python27-docutils
if [ $1 -eq 0 ]; then
  %{_sbindir}/update-alternatives \
    --update python %{_bindir}/python2.7 \
    --removeslave rst2html \
    --removeslave rst2latex \
    --removeslave rst2man \
    --removeslave rst2odt \
    --removeslave rst2odt_prepstyles \
    --removeslave rst2pseudoxml \
    --removeslave rst2s5 \
    --removeslave rst2xetex \
    --removeslave rst2xml \
    --removeslave rstpep2html \
 || :
fi

%files -n python26-docutils
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt THANKS.txt
%doc %{py26doc}/licenses %{py26doc}/docs %{py26doc}/tools/editors
%{python26_sitelib}/*
%{_bindir}/*-2.6
%ghost %{_bindir}/rst2html
%ghost %{_bindir}/rst2latex
%ghost %{_bindir}/rst2man
%ghost %{_bindir}/rst2odt
%ghost %{_bindir}/rst2odt_prepstyles
%ghost %{_bindir}/rst2pseudoxml
%ghost %{_bindir}/rst2s5
%ghost %{_bindir}/rst2xetex
%ghost %{_bindir}/rst2xml
%ghost %{_bindir}/rstpep2html

%files -n python27-docutils
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt THANKS.txt
%doc %{py27doc}/licenses %{py27doc}/docs %{py27doc}/tools/editors
%{python27_sitelib}/*
%{_bindir}/*-2.7
%ghost %{_bindir}/rst2html
%ghost %{_bindir}/rst2latex
%ghost %{_bindir}/rst2man
%ghost %{_bindir}/rst2odt
%ghost %{_bindir}/rst2odt_prepstyles
%ghost %{_bindir}/rst2pseudoxml
%ghost %{_bindir}/rst2s5
%ghost %{_bindir}/rst2xetex
%ghost %{_bindir}/rst2xml
%ghost %{_bindir}/rstpep2html

%changelog
* Fri Feb 27 2015 Ben Cressey <bcressey@amazon.com>
- add alternatives for docutils

* Tue Feb 3 2015 Ben Cressey <bcressey@amazon.com>
- build for multiple pythons

* Thu Sep 5 2013 Lee Trager <ltrager@amazon.com>
- import source package F20/python-docutils-0.11-1.fc20

* Thu Aug 15 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 0.11-1
- 0.11 final tarball.
- Remove flash file from the install (it was only used to run the unittests anyhow)

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-0.2.20130715svn7687
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 31 2013 Lee Trager <ltrager@amazon.com>
- Use unittest2 if availible
- import source package F19/python-docutils-0.11-0.1.20130715svn7687.fc19

* Mon Jul 15 2013 Matej Stuchlik <mstuchli@redhat.com> - 0.11-0.1.20130715svn7687
- Rebased to new snapshot
- Removed unnecessary patches

* Thu Mar 21 2013 Toshio Kuratomi <toshio@fedoraproject.org> - 0.10-0.8.20120824svn7502
- Add python3-imaging support :-)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-0.7.20120824svn7502
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 10 2013 Lee Trager <ltrager@amazon.com>
- Depend on python-devel, not python2-devel
- Only list python3 files when building for python3
- import source package F17/python-docutils-0.8.1-3.fc17

* Sat Aug 25 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.10-0.6.20120824svn7502
- Further fix of places in the code that use__import__

* Fri Aug 24 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.10-0.5.20120824svn7502
- Rebase to new snapshot with some fixes integrated
- Reenable one test that I can't replicate the failure with.

* Fri Aug 24 2012 David Malcolm <dmalcolm@redhat.com> - 0.10-0.4.20120730svn7490
- fix/disable failing tests with python 3.3

* Tue Aug 14 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.10-0.3.20120730svn7490
- PyXML patch from upstream
- Fix ability to disable python3 builds

* Fri Aug  3 2012 David Malcolm <dmalcolm@redhat.com> - 0.10-0.2.20120730svn7490
- remove rhel logic from with_python3 conditional

* Mon Jul 30 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.10-0.1.20120730svn7490
- Update to snapshot that's supposed to take care of the date directive unicode
  problem in a different way
- Patch to fix PyXML conflict without using rpm conflicts

* Fri Jul 20 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.9.1-1
- New update from upstream
- Fixes for previous patches incorporated there
- roman.py has been moved into a docutils submodule
- docutils doesn't work with PyXML.  before I poke around for the bug in PyXML,
  seeing if we're going to go through with deprecating it or if we can sanitize
  our python stdlib's handling of it.
- Fix for traceback in https://bugzilla.redhat.com/show_bug.cgi?id=786867

* Mon Jan 30 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.8.1-2
- Fix a unicode traceback https://bugzilla.redhat.com/show_bug.cgi?id=785622

* Thu Jan 5 2012 Toshio Kuratomi <toshio@fedoraproject.org> - 0.8.1-1
- Update to new upstream that has properly licensed files and a few bugfixes
- Add a patch to fix tracebacks when wrong values are given to CLI apps

* Wed Jul 20 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 0.8-2
- Replace the Apache licensed files with BSD licensed versions from upstream

* Tue Jul 12 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 0.8-1
- Upgrade to 0.8 final.
- Remove the two remaining Apache licensed files until their license is fixed.
- Patch regressions that we had already submitted upstream -- resubmit

* Tue May 17 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 0.8-0.1.20110517svn7036
- Ship a snapshot of 0.8 so that we can build on python-3.2.1
- Unfortunately, 3.2.1 isn't out yet either.  So also apply a fix for building
  with 3.2.0 that we'll need to remove later.
- The new docutils.math module is licensed Apache.  Update the license to reflect this

* Wed Mar 16 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 0.7-5
- Fix building with python-3.2 via a workaround.  Sent upstream awaiting
  feedback or a better fix.  Built in rawhide.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 1 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 0.7-3
- Fix scripts so they're the python2 versions not the python3 versions

* Thu Dec 30 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 0.7-2
- Build for python3

* Sun Aug 1 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 0.7-1
- Update for 0.7 release

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.6-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Jul 9 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/python-docutils-0.6-1.el6
- import source package RHEL6/python-docutils-0.5-4.1.el6
- setup complete for package python-docutils

* Tue Jan 19 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 0.6-1
- Update for 0.6 release.
- Switch from setuptools installed egg-info to distutils egg-info.  Note that
  this works because we're also changing docutils version.  To do this between
  0.5-4 and 0.5-5, for instance, we'd need to have %%preun scriptlet to get rid
  of the egg-info directory.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.5-2
- Rebuild for Python 2.6

* Wed Aug 6 2008 Toshio Kuratomi <toshio@fedoraproject.org> 0.5-1
- New upstream version.

* Mon Mar 3 2008 Toshio Kuratomi <toshio@fedoraproject.org> 0.4-8
- Use regular Requires syntax for python-imaging as missingok is just wrong.

* Thu Sep 27 2007 Toshio Kuratomi <a.badger@gmail.com> 0.4-7
- Build egg info.

* Mon Aug 13 2007 Toshio Kuratomi <a.badger@gmail.com> 0.4-6
- Last version had both the old and new rst.el.  Try again with only
  the new one.

* Sun Aug 12 2007 Toshio Kuratomi <a.badger@gmail.com> 0.4-5
- Make License tag conform to the new Licensing Policy.
- Fix the rst emacs mode (RH BZ 250100)

* Sat Dec 09 2006 Toshio Kuratomi <toshio-tiki-lounge.com> 0.4-4
- Bump and rebuild for python 2.5 in devel.

* Tue Aug 29 2006 Toshio Kuratomi <toshio-tiki-lounge.com> 0.4-3
- Bump for FC6 rebuild.
- Remove python byte compilation as this is handled automatically in FC4+.
- No longer %%ghost .pyo files.

* Thu Feb 16 2006 Toshio Kuratomi <toshio-tiki-lounge.com> 0.4-2
- Bump and rebuild for FC5.

* Sun Jan 15 2006 Toshio Kuratomi <toshio-tiki-lounge.com> 0.4-1
- Update to 0.4.
- Scripted the listing of files in the python module.
- Add a missingok requirement on python-imaging as docutils can make use of
  it when converting to formats that have images.

* Tue Jun 7 2005 Toshio Kuratomi <toshio-tiki-lounge.com> 0.3.9-1
- Update to version 0.3.9.
- Use a dist tag as there aren't any differences between supported fc
  releases (FC3, FC4, devel.)

* Thu May 12 2005 Toshio Kuratomi <toshio-tiki-lounge.com> 0.3.7-7
- Bump version and rebuild to sync across architectures.

* Sun Mar 20 2005 Toshio Kuratomi <toshio-tiki-lounge.com> 0.3.7-6
- Rebuild for FC4t1

* Sat Mar 12 2005 Toshio Kuratomi <toshio.tiki-lounge.com> 0.3.7-5
- Add GPL as a license (mschwendt)
- Use versioned Obsoletes and Provides (mschwendt)

* Fri Mar 04 2005 Toshio Kuratomi <toshio.tiki-lounge.com> 0:0.3.7-4
- Rename to python-docutils per the new packaging guidelines.

* Wed Jan 12 2005 Toshio Kuratomi <toshio.tiki-lounge.com> 0:0.3.7-0.fdr.3
- Really install roman.py and build roman.py[co].  Needed to make sure I have
  docutils installed to test that it builds roman.py fine in that case.

* Tue Jan 11 2005 Toshio Kuratomi <toshio.tiki-lounge.com> 0:0.3.7-0.fdr.2
- Special case roman.py to always install.  This is the behaviour we want
  unless something else provides it.  Will need to watch out for this in
  future Core and Extras packages, but the auto detection code makes it
  possible that builds will not be reproducible if roman.py were installed
  from another package.... Lesser of two evils here.
- Provide python-docutils in case that package were preinstalled from
  another repository.

* Fri Dec 31 2004 Toshio Kuratomi <toshio.tiki-lounge.com> 0:0.3.7-0.fdr.1
- Update to 0.3.7
- Rename from python-docutils to docutils.
- Make roman.py optionally a part of the files list.  In FC2, this will be
  included.  In FC3, this won't.
- BuildConflict with self since the docutils build detects the presence
  of roman.py and doesn't reinstall itself.

* Mon Aug 9 2004 Toshio Kuratomi <toshio.tiki-lounge.com> 0:0.3.5-0.fdr.1
- Update to 0.3.5.
- Update spec style to latest fedora-rpmdevtools.
- Merge everything into a single package.  There isn't very much space
  advantage to having separate packages in a package this small and in
  this case, the documentation on using docutils as a library is also a
  good example of how to write in ReSructuredText.

* Sat Jan 10 2004 Michel Alexandre Salim <salimma[AT]users.sf.net> 0:0.3-0.fdr.1
- Initial RPM release.
